@@ -27,7 +27,7 @@ use UI::Dialog::Backend;
 BEGIN {
     use vars qw( $VERSION @ISA );
     @ISA = qw( UI::Dialog::Backend );
-    $VERSION = '1.04';
+    $VERSION = '1.05';
 }
 
 #::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
@@ -43,6 +43,14 @@ sub new {
     $self->{'_state'} = {};
     $self->{'_opts'} = {};
 
+	#: Dynamic path discovery...
+	my $CFG_PATH = $cfg->{'PATH'};
+	if (ref($CFG_PATH) eq "ARRAY") { $self->{'PATHS'} = $CFG_PATH; }
+	elsif ($CFG_PATH =~ m!:!) { $self->{'PATHS'} = [ split(/:/,$CFG_PATH) ]; }
+	elsif (-d $CFG_PATH) { $self->{'PATHS'} = [ $CFG_PATH ]; }
+	elsif ($ENV{'PATH'}) { $self->{'PATHS'} = [ split(/:/,$ENV{'PATH'}) ]; }
+	else { $self->{'PATHS'} = ''; }
+
     $self->{'_opts'}->{'debug'} = $cfg->{'debug'} || undef();
 
 	$self->{'_opts'}->{'literal'} = $cfg->{'literal'} || 0;
@@ -723,6 +731,7 @@ sub calendar {
     if ($rv && $rv >= 1) {
 		$this_rv = 0;
     } else {
+		chomp($selected);
 		$self->ra(split(/\//,$selected));
 		$self->rs($selected);
 		$this_rv = $selected;
